@@ -156,7 +156,7 @@ class PW:
 
         self.elf: Optional[ELF] = None  # type: ignore
         self.libc: Optional[ELF] = None  # type: ignore
-        self.libs: Dict[str, ELF] = {}
+        self.libs: Dict[str, ELF] = {}  # type: ignore
 
         if self.binary is not None and not self.binary.is_file():
             raise FileNotFoundError(f"{self.binary} is not a file")
@@ -233,12 +233,12 @@ class PW:
         Check the security of the binary.
         """
         for lib, elf in self.libs.items():
-            if elf.path != self.elf.path:
+            if (self.elf is not None and elf.path != self.elf.path) or self.elf is None:
                 l.info(f"Checksec info for library: {lib}")
                 for ln in elf.checksec().splitlines():
                     l.info(ln)
         if self.elf is not None:
-            l.info(f"Checksec info for main object: {self.binary.name}")
+            l.info(f"Checksec info for main object: {self.elf.path}")
             for ln in self.elf.checksec().splitlines():
                 l.info(ln)
 
@@ -250,7 +250,7 @@ class PW:
 
         :return: All data received from the remote tube.
         """
-        b = self.recvall()
+        b: bytes = self.recvall()
         print(b)
         return b
 
@@ -283,6 +283,6 @@ class PW:
         :param drop: Whether to drop the delimiter.
         :return: The data received from the remote tube.
         """
-        b = self.recvuntil(delim, drop=drop)
+        b: bytes = self.recvuntil(delim, drop=drop)
         print(b)
         return b
